validate

package
v0.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 21, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Func

type Func[T any] func(ctx context.Context, req *T) error

Func is a typed validation function for request structs. Used as a complement to binding tags for cross-field / business-rule checks.

Jump to